@@ -6,6 +6,7 @@ from datetime import datetime, timedelta
 # from dateutil.parser import parse
 import jieba.posseg as psg
 import jieba
+import pkg_resources
 import os
 
 
@@ -226,7 +227,12 @@ def time_extract(text):
     keyDate = {'今天': 0, '明天': 1, '后天': 2, '昨天': -1, '前天': -2}
     timedic = ['时', '分', '到']
     tmptext = []
-    jieba.load_userdict("../rule_date/dict.txt")  # 自定义分词词典
+    path = './rule_date/dict.txt'
+    if not path:
+        path = pkg_resources.resource_filename(
+            __name__, "./rule_date/dict.txt"
+        )
+    jieba.load_userdict(path)  # 自定义分词词典
     for k, v in psg.cut(text):  # k: 词语, v: 词性
         tmptext.append([k, v])
     for i in range(len(tmptext)):
